@@ -277,7 +277,11 @@ sub angle_lines {
     while (time < $s) {
         $F->set_color({ 'red' => int(rand(256)), 'green' => int(rand(256)), 'blue' => int(rand(256)) });
         $F->angle_line({ 'x' => $center_x, 'y' => $center_y, 'radius' => ($center_y - $F->{'Y_CLIP'}), 'angle' => $angle, 'antialiased' => $aa });
-        $angle += 1.1;
+	if ($F->{'ACCELERATED'} && ! $aa) {
+	    $angle += .1;
+	} else {
+	    $angle += 1.1;
+	}
         $angle -= 360 if ($angle >= 360);
     } ## end while (time < $s)
 } ## end sub angle_lines
