@@ -725,7 +725,8 @@ END_C
 };
 
 BEGIN {
-    our $VERSION = 1.00;
+    require Exporter;
+    our $VERSION = 1.01;
     our @EXPORT_OK = qw(c_monochrome c_convert_16_24 c_convert_24_16 c_get_screen_info c_plot c_line c_blit_write c_flip_vertical c_flip_horizontal c_rotate );
     our @EXPORT    = qw( $INLINE );
 }
@@ -738,7 +739,8 @@ sub _convert_16_to_24 {
     my $size    = length($img);
     if ($self->{'ACCELERATED'}) {
         my $new_img = chr(0) x (($size/2)*3);
-        c_convert_16_24($img,$size,$new_img,$color_order); return($new_img);
+        c_convert_16_24($img,$size,$new_img,$color_order);
+        return($new_img);
     }
     my $new_img = '';
     my $black24 = chr(0) x 3;
@@ -771,7 +773,8 @@ sub _convert_24_to_16 {
     my $size    = length($img);
     if ($self->{'ACCELERATED'}) {
         my $new_img = chr(0) x (($size/3)*2);
-        c_convert_24_16($img,$size,$new_img,$color_order);return($new_img);
+        c_convert_24_16($img,$size,$new_img,$color_order);
+        return($new_img);
     }
     my $new_img = '';
     my $black24 = chr(0) x 3;
@@ -1446,13 +1449,30 @@ sub blit_transform {
     } ## end if (exists($params->{'merge'...}))
     if (exists($params->{'flip'})) {
         my $image = $params->{'blit_data'}->{'image'};
-        my $new   = "$image";
-        if (lc($params->{'flip'}) eq 'vertical') {
-            c_flip_vertical($new,$width,$height,$bytes);
-        } elsif (lc($params->{'flip'}) eq 'horizontal') {
-            c_flip_horizontal($new,$width,$height,$bytes);
-        } elsif (lc($params->{'flip'}) eq 'both') {
-            c_flip_both($new,$width,$height,$bytes);
+        my $new   = '';
+        if ($self->{'ACCELERATED'}) {
+            $new = "$image";
+            if (lc($params->{'flip'}) eq 'vertical') {
+                c_flip_vertical($new,$width,$height,$bytes);
+            } elsif (lc($params->{'flip'}) eq 'horizontal') {
+                c_flip_horizontal($new,$width,$height,$bytes);
+            } elsif (lc($params->{'flip'}) eq 'both') {
+                c_flip_both($new,$width,$height,$bytes);
+            }
+        } else {
+            if (lc($params->{'flip'}) eq 'vertical') {
+                for (my $y = ($height - 1); $y >= 0; $y--) {
+                    $new .= substr($image, ($y * $bline), $bline);
+                }
+            } elsif (lc($params->{'flip'}) eq 'horizontal') {
+                foreach my $y (0 .. ($height - 1)) {
+                    for (my $x = ($width - 1); $x >= 0; $x--) {
+                        $new .= substr($image, (($x * $bytes) + ($y * $bline)), $bytes);
+                    }
+                }
+            } else {
+                $new = "$image";
+            }
         }
         return (
             {
@@ -1473,7 +1493,7 @@ sub blit_transform {
             }
         }
         return ($params->{'blit_data'}) if (abs($degrees) == 360 || $degrees == 0);    # 0 and 360 are not a rotation
-        unless ($params->{'rotate'}->{'quality'} eq 'high') {
+        unless ($params->{'rotate'}->{'quality'} eq 'high' || ! $self->{'ACCELERATED'}) {
              if (abs($degrees) == 180) {
                 my $new = "$image";
                 c_flip_both($new,$width,$height,$bytes);
